Initializes a new package
1 2 | init_package(pkg_name, your_name = getOption("usethis.full_name"),
path = ".", check_cran_name = TRUE)
|
pkg_name |
the package name |
your_name |
your name. This defaults to the 'usethis.full_name' option. if this is NULL, then you will be prompted to type your name, which will then be stored as the 'usethis.full_name' option. |
path |
the directory path. Default is the current directory |
check_cran_name |
check if the name is already taken on CRAN |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.